summaryrefslogtreecommitdiffstats
path: root/lib
diff options
context:
space:
mode:
authorMarkus Roberts <Markus@reality.com>2010-08-21 19:44:06 -0700
committerMarkus Roberts <Markus@reality.com>2010-08-24 18:08:22 -0700
commitc3185584a0c9f22b7deaff022855b160a945486f (patch)
tree58d6b918c782173672439ad03450d24a545eed6b /lib
parent491c31dcbdb0977c0377cb276cfe32a4c24e0e1a (diff)
downloadpuppet-c3185584a0c9f22b7deaff022855b160a945486f.tar.gz
puppet-c3185584a0c9f22b7deaff022855b160a945486f.tar.xz
puppet-c3185584a0c9f22b7deaff022855b160a945486f.zip
Fix for #4489 -- apply was using the rest terminus
Basing pervasive low-level behaviour changes on the application name isn't a good idea, but if we're going to do it we need to remember to update the test when we rename the application. I am not certain that this change is globally correct; there may be other related problems that will not be fixed (and may in fact be exacerbated) by this patch.
Diffstat (limited to 'lib')
-rw-r--r--lib/puppet/file_serving/indirection_hooks.rb4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/puppet/file_serving/indirection_hooks.rb b/lib/puppet/file_serving/indirection_hooks.rb
index 7e0c17916..a85e90ef1 100644
--- a/lib/puppet/file_serving/indirection_hooks.rb
+++ b/lib/puppet/file_serving/indirection_hooks.rb
@@ -19,8 +19,8 @@ module Puppet::FileServing::IndirectionHooks
return PROTOCOL_MAP["file"] if request.key =~ /^#{::File::SEPARATOR}/
return PROTOCOL_MAP["file"] if request.protocol == "file"
- # We're heading over the wire the protocol is 'puppet' and we've got a server name or we're not named 'puppet'
- if request.protocol == "puppet" and (request.server or Puppet.settings[:name] != "puppet")
+ # We're heading over the wire the protocol is 'puppet' and we've got a server name or we're not named 'apply' or 'puppet'
+ if request.protocol == "puppet" and (request.server or !["puppet","apply"].include?(Puppet.settings[:name]))
return PROTOCOL_MAP["puppet"]
end